==> autoscalingplans-1.13.1.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/autoscalingplans/CfnScalingPlanProps.java <==
package software.amazon.awscdk.services.autoscalingplans;

/**
 * Properties for defining a `AWS::AutoScalingPlans::ScalingPlan`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-15T19:45:44.301Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnScalingPlanProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::AutoScalingPlans::ScalingPlan.ApplicationSource`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html#cfn-autoscalingplans-scalingplan-applicationsource
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getApplicationSource();

    /**
     * `AWS::AutoScalingPlans::ScalingPlan.ScalingInstructions`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html#cfn-autoscalingplans-scalingplan-scalinginstructions
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getScalingInstructions();

    /**
     * @return a {@link Builder} of {@link CfnScalingPlanProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnScalingPlanProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.Object applicationSource;
        private java.lang.Object scalingInstructions;

        /**
         * Sets the value of ApplicationSource
         * @param applicationSource `AWS::AutoScalingPlans::ScalingPlan.ApplicationSource`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder applicationSource(software.amazon.awscdk.services.autoscalingplans.CfnScalingPlan.ApplicationSourceProperty applicationSource) {
            this.applicationSource = applicationSource;
            return this;
        }

        /**
         * Sets the value of ApplicationSource
         * @param applicationSource `AWS::AutoScalingPlans::ScalingPlan.ApplicationSource`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder applicationSource(software.amazon.awscdk.core.IResolvable applicationSource) {
            this.applicationSource = applicationSource;
            return this;
        }

        /**
         * Sets the value of ScalingInstructions
         * @param scalingInstructions `AWS::AutoScalingPlans::ScalingPlan.ScalingInstructions`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder scalingInstructions(software.amazon.awscdk.core.IResolvable scalingInstructions) {
            this.scalingInstructions = scalingInstructions;
            return this;
        }

        /**
         * Sets the value of ScalingInstructions
         * @param scalingInstructions `AWS::AutoScalingPlans::ScalingPlan.ScalingInstructions`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder scalingInstructions(java.util.List<java.lang.Object> scalingInstructions) {
            this.scalingInstructions = scalingInstructions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnScalingPlanProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnScalingPlanProps build() {
            return new Jsii$Proxy(applicationSource, scalingInstructions);
        }
    }

    /**
     * An implementation for {@link CfnScalingPlanProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnScalingPlanProps {
        private final java.lang.Object applicationSource;
        private final java.lang.Object scalingInstructions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.applicationSource = this.jsiiGet("applicationSource", java.lang.Object.class);
            this.scalingInstructions = this.jsiiGet("scalingInstructions", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.Object applicationSource, java.lang.Object scalingInstructions) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.applicationSource = java.util.Objects.requireNonNull(applicationSource, "applicationSource is required");
            this.scalingInstructions = java.util.Objects.requireNonNull(scalingInstructions, "scalingInstructions is required");
        }

        @Override
        public java.lang.Object getApplicationSource() {
            return this.applicationSource;
        }

        @Override
        public java.lang.Object getScalingInstructions() {
            return this.scalingInstructions;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("applicationSource", om.valueToTree(this.getApplicationSource()));
            obj.set("scalingInstructions", om.valueToTree(this.getScalingInstructions()));
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnScalingPlanProps.Jsii$Proxy that = (CfnScalingPlanProps.Jsii$Proxy) o;

            if (!applicationSource.equals(that.applicationSource)) return false;
            return this.scalingInstructions.equals(that.scalingInstructions);
        }

        @Override
        public int hashCode() {
            int result = this.applicationSource.hashCode();
            result = 31 * result + (this.scalingInstructions.hashCode());
            return result;
        }
    }
}

==> autoscalingplans-1.16.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/autoscalingplans/CfnScalingPlanProps.java <==
package software.amazon.awscdk.services.autoscalingplans;

/**
 * Properties for defining a `AWS::AutoScalingPlans::ScalingPlan`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.2 (build faba0be)", date = "2019-11-11T17:17:47.281Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.autoscalingplans.$Module.class, fqn = "@aws-cdk/aws-autoscalingplans.CfnScalingPlanProps")
@software.amazon.jsii.Jsii.Proxy(CfnScalingPlanProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnScalingPlanProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::AutoScalingPlans::ScalingPlan.ApplicationSource`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html#cfn-autoscalingplans-scalingplan-applicationsource
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getApplicationSource();

    /**
     * `AWS::AutoScalingPlans::ScalingPlan.ScalingInstructions`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscalingplans-scalingplan.html#cfn-autoscalingplans-scalingplan-scalinginstructions
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getScalingInstructions();

    /**
     * @return a {@link Builder} of {@link CfnScalingPlanProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnScalingPlanProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.Object applicationSource;
        private java.lang.Object scalingInstructions;

        /**
         * Sets the value of ApplicationSource
         * @param applicationSource `AWS::AutoScalingPlans::ScalingPlan.ApplicationSource`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder applicationSource(software.amazon.awscdk.services.autoscalingplans.CfnScalingPlan.ApplicationSourceProperty applicationSource) {
            this.applicationSource = applicationSource;
            return this;
        }

        /**
         * Sets the value of ApplicationSource
         * @param applicationSource `AWS::AutoScalingPlans::ScalingPlan.ApplicationSource`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder applicationSource(software.amazon.awscdk.core.IResolvable applicationSource) {
            this.applicationSource = applicationSource;
            return this;
        }

        /**
         * Sets the value of ScalingInstructions
         * @param scalingInstructions `AWS::AutoScalingPlans::ScalingPlan.ScalingInstructions`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder scalingInstructions(software.amazon.awscdk.core.IResolvable scalingInstructions) {
            this.scalingInstructions = scalingInstructions;
            return this;
        }

        /**
         * Sets the value of ScalingInstructions
         * @param scalingInstructions `AWS::AutoScalingPlans::ScalingPlan.ScalingInstructions`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder scalingInstructions(java.util.List<java.lang.Object> scalingInstructions) {
            this.scalingInstructions = scalingInstructions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnScalingPlanProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnScalingPlanProps build() {
            return new Jsii$Proxy(applicationSource, scalingInstructions);
        }
    }

    /**
     * An implementation for {@link CfnScalingPlanProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnScalingPlanProps {
        private final java.lang.Object applicationSource;
        private final java.lang.Object scalingInstructions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.applicationSource = this.jsiiGet("applicationSource", java.lang.Object.class);
            this.scalingInstructions = this.jsiiGet("scalingInstructions", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.Object applicationSource, final java.lang.Object scalingInstructions) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.applicationSource = java.util.Objects.requireNonNull(applicationSource, "applicationSource is required");
            this.scalingInstructions = java.util.Objects.requireNonNull(scalingInstructions, "scalingInstructions is required");
        }

        @Override
        public java.lang.Object getApplicationSource() {
            return this.applicationSource;
        }

        @Override
        public java.lang.Object getScalingInstructions() {
            return this.scalingInstructions;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("applicationSource", om.valueToTree(this.getApplicationSource()));
            data.set("scalingInstructions", om.valueToTree(this.getScalingInstructions()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-autoscalingplans.CfnScalingPlanProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnScalingPlanProps.Jsii$Proxy that = (CfnScalingPlanProps.Jsii$Proxy) o;

            if (!applicationSource.equals(that.applicationSource)) return false;
            return this.scalingInstructions.equals(that.scalingInstructions);
        }

        @Override
        public int hashCode() {
            int result = this.applicationSource.hashCode();
            result = 31 * result + (this.scalingInstructions.hashCode());
            return result;
        }
    }
}
